==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ACmpBinop.h <==
// public final class soot.jimple.parser.node.ACmpBinop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ffef953d70d5c3c7 soot_jimple_parser_node_ACmpBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_ACmpBinop_H_
#define _JC_soot_jimple_parser_node_ACmpBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TCmp$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACmpBinop$sub_refs	_jc_soot_jimple_parser_node_ACmpBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACmpBinop$sub_nonrefs	_jc_soot_jimple_parser_node_ACmpBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpBinop$refs	_jc_soot_jimple_parser_node_ACmpBinop$refs;
typedef struct _jc_soot_jimple_parser_node_ACmpBinop$nonrefs	_jc_soot_jimple_parser_node_ACmpBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpBinop$object	_jc_soot_jimple_parser_node_ACmpBinop$object;

typedef const struct _jc_soot_jimple_parser_node_ACmpBinop$vmethods	_jc_soot_jimple_parser_node_ACmpBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACmpBinop$vtable	_jc_soot_jimple_parser_node_ACmpBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACmpBinop$vtype	_jc_soot_jimple_parser_node_ACmpBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACmpBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *);
extern void _jc_soot_jimple_parser_node_ACmpBinop$method$_init$25980d7a4eef4668(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *, struct _jc_soot_jimple_parser_node_TCmp$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACmpBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACmpBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *);
extern struct _jc_soot_jimple_parser_node_TCmp$object *_jc_soot_jimple_parser_node_ACmpBinop$method$getCmp$9ba477808e7198fe(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *);
extern void _jc_soot_jimple_parser_node_ACmpBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACmpBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACmpBinop$method$setCmp$ce9fa040c8037187(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *, struct _jc_soot_jimple_parser_node_TCmp$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACmpBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACmpBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACmpBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACmpBinop$method_info$getCmp$9ba477808e7198fe;
extern _jc_method _jc_soot_jimple_parser_node_ACmpBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACmpBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACmpBinop$method_info$setCmp$ce9fa040c8037187;
extern _jc_method _jc_soot_jimple_parser_node_ACmpBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACmpBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *);
	struct _jc_soot_jimple_parser_node_TCmp$object	*(*getCmp$9ba477808e7198fe)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setCmp$ce9fa040c8037187)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *, struct _jc_soot_jimple_parser_node_TCmp$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ACmpBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_ACmpBinop$vmethods	soot_jimple_parser_node_ACmpBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACmpBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACmpBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TCmp$object	*__5fcmp__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpBinop$refs {
    _jc_soot_jimple_parser_node_ACmpBinop$sub_refs	soot_jimple_parser_node_ACmpBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_ACmpBinop$sub_nonrefs	soot_jimple_parser_node_ACmpBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACmpBinop$object {
	_jc_soot_jimple_parser_node_ACmpBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACmpBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACmpBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACmpBinop$vtype _jc_soot_jimple_parser_node_ACmpBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACmpBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACmpBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACmpBinop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ACmpBinop.h <==
// public final class soot.jimple.parser.node.ACmpBinop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ffef953d70d5c3c7 soot_jimple_parser_node_ACmpBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_ACmpBinop_H_
#define _JC_soot_jimple_parser_node_ACmpBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TCmp$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACmpBinop$sub_refs	_jc_soot_jimple_parser_node_ACmpBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACmpBinop$sub_nonrefs	_jc_soot_jimple_parser_node_ACmpBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpBinop$refs	_jc_soot_jimple_parser_node_ACmpBinop$refs;
typedef struct _jc_soot_jimple_parser_node_ACmpBinop$nonrefs	_jc_soot_jimple_parser_node_ACmpBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpBinop$object	_jc_soot_jimple_parser_node_ACmpBinop$object;

typedef const struct _jc_soot_jimple_parser_node_ACmpBinop$vmethods	_jc_soot_jimple_parser_node_ACmpBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACmpBinop$vtable	_jc_soot_jimple_parser_node_ACmpBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACmpBinop$vtype	_jc_soot_jimple_parser_node_ACmpBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACmpBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpBinop$method$_init$25980d7a4eef4668(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *, struct _jc_soot_jimple_parser_node_TCmp$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACmpBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACmpBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TCmp$object *_jc_soot_jimple_parser_node_ACmpBinop$method$getCmp$9ba477808e7198fe(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpBinop$method$setCmp$ce9fa040c8037187(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *, struct _jc_soot_jimple_parser_node_TCmp$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACmpBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACmpBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACmpBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACmpBinop$method_info$getCmp$9ba477808e7198fe;
extern _jc_method _jc_soot_jimple_parser_node_ACmpBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACmpBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACmpBinop$method_info$setCmp$ce9fa040c8037187;
extern _jc_method _jc_soot_jimple_parser_node_ACmpBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACmpBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TCmp$object	*(*getCmp$9ba477808e7198fe)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setCmp$ce9fa040c8037187)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *, struct _jc_soot_jimple_parser_node_TCmp$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpBinop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ACmpBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_ACmpBinop$vmethods	soot_jimple_parser_node_ACmpBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACmpBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACmpBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TCmp$object	*__5fcmp__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpBinop$refs {
    _jc_soot_jimple_parser_node_ACmpBinop$sub_refs	soot_jimple_parser_node_ACmpBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_ACmpBinop$sub_nonrefs	soot_jimple_parser_node_ACmpBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACmpBinop$object {
	_jc_soot_jimple_parser_node_ACmpBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACmpBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACmpBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACmpBinop$vtype _jc_soot_jimple_parser_node_ACmpBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACmpBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACmpBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACmpBinop_H_ */
